@@ -17,10 +17,12 @@ import io
 import os
 import logging
 import platform
+from pathlib import Path
 
 from stevedore import extension
 import yaml
 
+from jenkins_jobs.errors import JenkinsJobsException
 from jenkins_jobs.cli.parser import create_parser
 from jenkins_jobs.config import JJBConfig
 from jenkins_jobs import utils
@@ -126,7 +128,9 @@ class JenkinsJobs(object):
                 self.options.path = [self.options.path]
             else:
                 # take list of paths
-                self.options.path = self.options.path.split(os.pathsep)
+                self.options.path = [
+                    Path(p) for p in self.options.path.split(os.pathsep)
+                ]
 
                 do_recurse = (
                     getattr(self.options, "recursive", False)
@@ -142,7 +146,7 @@ class JenkinsJobs(object):
                         paths.extend(utils.recurse_path(path, excludes))
                     else:
                         paths.append(path)
-                self.options.path = paths
+                self.options.path = [Path(p) for p in paths]
 
     def execute(self):
 
@@ -171,7 +175,13 @@ def main():
 
     argv = sys.argv[1:]
     jjb = JenkinsJobs(argv)
-    jjb.execute()
+    try:
+        jjb.execute()
+    except JenkinsJobsException as x:
+        print(file=sys.stderr)
+        for line in x.lines:
+            print(line, file=sys.stderr)
+        sys.exit(1)
 
 
 if __name__ == "__main__":
