@@ -14,6 +14,8 @@
 
 # Base class for a jenkins_jobs module
 
+from jenkins_jobs.loc_loader import LocList
+
 
 class Base(object):
     """
@@ -46,15 +48,15 @@ class Base(object):
     def __init__(self, registry):
         self.registry = registry
 
-    def handle_data(self, job_data):
+    def amend_job_dict(self, job):
         """This method is called before any XML is generated.  By
-        overriding this method, a module may arbitrarily modify a data
-        structure which will probably be the JJB YamlParser's intermediate data
+        overriding this method, a module may arbitrarily modify a job data
+        structure which will probably be the JJB Job intermediate data dict
         representation. If it has changed the data structure at all, it must
         return ``True``, otherwise, it must return ``False``.
 
-        :arg dict job_data: the intermediate representation of job data
-            loaded from JJB Yaml files without variables interpolation or other
+        :arg dict job: the intermediate representation of job data
+            loaded from JJB Yaml files after variables interpolation and other
             yaml expansions.
 
         :rtype: bool
@@ -68,9 +70,26 @@ class Base(object):
         Element objects and add them to the xml_parent.  The YAML data
         structure must not be modified.
 
-        :arg YAMLParser parser: the global YAML Parser
-        :arg Element xml_parent: the parent XML element
+        :arg class:`xml.etree.ElementTree` xml_parent: the parent XML element
         :arg dict data: the YAML data structure
         """
 
         pass
+
+    def dispatch_component_list(
+        self, component_type, component_list, xml_parent, job_data=None
+    ):
+        if not component_list:
+            return
+        for idx, component in enumerate(component_list):
+            if isinstance(component_list, LocList):
+                pos = component_list.value_pos[idx]
+            else:
+                pos = None
+            self.registry.dispatch(
+                component_type,
+                xml_parent,
+                component,
+                job_data=job_data,
+                component_pos=pos,
+            )
