@@ -34,6 +34,7 @@ Example::
 
 import xml.etree.ElementTree as XML
 
+from jenkins_jobs.loc_loader import LocList
 from jenkins_jobs.errors import JenkinsJobsException
 from jenkins_jobs.errors import MissingAttributeError
 from jenkins_jobs.errors import InvalidAttributeError
@@ -1237,13 +1238,13 @@ def active_choices_param(registry, xml_parent, data):
     Minimal Example:
 
     .. literalinclude::
-        /../../tests/yamlparser/fixtures/active-choices-param001.yaml
+        /../../tests/yamlparser/job_fixtures/active-choices-param001.yaml
        :language: yaml
 
     Full Example:
 
     .. literalinclude::
-        /../../tests/yamlparser/fixtures/active-choices-param002.yaml
+        /../../tests/yamlparser/job_fixtures/active-choices-param002.yaml
        :language: yaml
     """
     element_name = "org.biouno.unochoice.ChoiceParameter"
@@ -1295,13 +1296,13 @@ def active_choices_reactive_param(registry, xml_parent, data):
     Minimal Example:
 
     .. literalinclude::
-        /../../tests/yamlparser/fixtures/active-choices-reactive-param001.yaml
+        /../../tests/yamlparser/job_fixtures/active-choices-reactive-param001.yaml
        :language: yaml
 
     Full Example:
 
     .. literalinclude::
-        /../../tests/yamlparser/fixtures/active-choices-reactive-param002.yaml
+        /../../tests/yamlparser/job_fixtures/active-choices-reactive-param002.yaml
        :language: yaml
     """
 
@@ -1391,13 +1392,13 @@ def dynamic_reference_param(registry, xml_parent, data):
     Minimal Example:
 
     .. literalinclude::
-        /../../tests/yamlparser/fixtures/dynamic-reference-param001.yaml
+        /../../tests/yamlparser/job_fixtures/dynamic-reference-param001.yaml
        :language: yaml
 
     Full Example:
 
     .. literalinclude::
-        /../../tests/yamlparser/fixtures/dynamic-reference-param002.yaml
+        /../../tests/yamlparser/job_fixtures/dynamic-reference-param002.yaml
        :language: yaml
     """
     element_name = "org.biouno.unochoice.DynamicReferenceParameter"
@@ -1431,12 +1432,178 @@ def dynamic_reference_param(registry, xml_parent, data):
     helpers.convert_mapping_to_xml(pdef, data, mapping, fail_required=True)
 
 
+def persistent_string_param(registry, xml_parent, data):
+    """yaml: persistent-string
+    A persistent string parameter.
+
+    Requires the Jenkins :jenkins-plugins:`Persistent Parameter Plugin
+    <persistent-parameter>`.
+
+    :arg str name: the name of the parameter
+    :arg str default: the default value of the parameter (optional)
+    :arg str description: a description of the parameter (optional)
+    :arg bool trim: strip whitespaces from the begnning and end
+        of the string (optional, default: false)
+    :arg bool successfulOnly: if true, then the value of the parameter
+        gets persisted only between successful builds
+        (optional, default: false)
+
+    Example::
+
+      parameters:
+        - persistent-string:
+            name: FOO
+            default: bar
+            description: "A parameter named FOO, defaults to 'bar'."
+            trim: false
+            successfulOnly: false
+    """
+    pdef = base_param(
+        registry,
+        xml_parent,
+        data,
+        True,
+        "com.gem.persistentparameter.PersistentStringParameterDefinition",
+    )
+
+    mapping = [("trim", "trim", False), ("successfulOnly", "successfulOnly", False)]
+    helpers.convert_mapping_to_xml(pdef, data, mapping, fail_required=True)
+
+
+def persistent_bool_param(registry, xml_parent, data):
+    """yaml: persistent-bool
+    A persistent boolean parameter.
+
+    Requires the Jenkins :jenkins-plugins:`Persistent Parameter Plugin
+    <persistent-parameter>`.
+
+    :arg str name: the name of the parameter
+    :arg str default: the default value of the parameter (optional)
+    :arg str description: a description of the parameter (optional)
+    :arg bool successfulOnly: if true, then the value of the parameter
+        gets persisted only between successful builds
+        (optional, default: false)
+
+    Example::
+
+      parameters:
+        - persistent-bool:
+            name: FOO
+            default: false
+            description: "A persistent parameter named FOO, defaults to 'false'."
+            successfulOnly: false
+    """
+    data["default"] = str(data.get("default", False)).lower()
+    pdef = base_param(
+        registry,
+        xml_parent,
+        data,
+        True,
+        "com.gem.persistentparameter.PersistentBooleanParameterDefinition",
+    )
+
+    mapping = [("successfulOnly", "successfulOnly", False)]
+    helpers.convert_mapping_to_xml(pdef, data, mapping, fail_required=True)
+
+
+def persistent_text_param(registry, xml_parent, data):
+    """yaml: persistent-text
+    A persistent text parameter.
+
+    Requires the Jenkins :jenkins-plugins:`Persistent Parameter Plugin
+    <persistent-parameter>`.
+
+    :arg str name: the name of the parameter
+    :arg str default: the default value of the parameter (optional)
+    :arg str description: a description of the parameter (optional)
+    :arg bool trim: strip whitespaces from the begnning and end
+        of the string (optional, default: false)
+    :arg bool successfulOnly: if true, then the value of the parameter
+        gets persisted only between successful builds
+        (optional, default: false)
+
+    Example::
+
+      parameters:
+        - persistent-text:
+            name: FOO
+            default: bar
+            description: "A persistent parameter named FOO, defaults to 'bar'."
+            successfulOnly: false
+    """
+
+    pdef = base_param(
+        registry,
+        xml_parent,
+        data,
+        True,
+        "com.gem.persistentparameter.PersistentTextParameterDefinition",
+    )
+
+    mapping = [("trim", "trim", False), ("successfulOnly", "successfulOnly", False)]
+    helpers.convert_mapping_to_xml(pdef, data, mapping, fail_required=True)
+
+
+def persistent_choice_param(registry, xml_parent, data):
+    """yaml: persistent-choice
+    A persistent single selection parameter.
+
+    Requires the Jenkins :jenkins-plugins:`Persistent Parameter Plugin
+    <persistent-parameter>`.
+
+    :arg str name: the name of the parameter
+    :arg list choices: the available choices, first one is the default one.
+    :arg str description: a description of the parameter (optional)
+    :arg bool successfulOnly: if true, then the value of the parameter
+        gets persisted only between successful builds
+        (optional, default: false)
+
+    Example::
+
+      parameters:
+        - persistent-choice:
+            name: project
+            choices:
+              - nova
+              - glance
+            description: "On which project to run?"
+            successfulOnly: false
+    """
+    pdef = base_param(
+        registry,
+        xml_parent,
+        data,
+        False,
+        "com.gem.persistentparameter.PersistentChoiceParameterDefinition",
+    )
+    choices = XML.SubElement(pdef, "choices", {"class": "java.util.Arrays$ArrayList"})
+    a = XML.SubElement(choices, "a", {"class": "string-array"})
+    for choice in data["choices"]:
+        XML.SubElement(a, "string").text = choice
+
+    mapping = [("successfulOnly", "successfulOnly", False)]
+    helpers.convert_mapping_to_xml(pdef, data, mapping, fail_required=True)
+
+
 class Parameters(jenkins_jobs.modules.base.Base):
     sequence = 21
 
     component_type = "parameter"
     component_list_type = "parameters"
 
+    @staticmethod
+    def _extend_uno_choice_param_data(param, param_type, data):
+        """Pass job name to the uno-choice plugin"""
+        if param_type in (
+            "active-choices",
+            "active-choices-reactive",
+            "dynamic-reference",
+        ):
+            # Extend uno-choice plugin parameter data with mandatory properties:
+            # `project-name` and `project-full-name`
+            param[param_type]["_project-name"] = data["name"].split("/")[-1]
+            param[param_type]["_project-full-name"] = data["name"]
+
     def gen_xml(self, xml_parent, data):
         properties = xml_parent.find("properties")
         if properties is None:
@@ -1458,37 +1625,26 @@ class Parameters(jenkins_jobs.modules.base.Base):
             pdefs = pdefp.find("parameterDefinitions")
             if pdefs is None:
                 pdefs = XML.SubElement(pdefp, "parameterDefinitions")
-            for param in parameters:
-                # Pass job name to the uno-choice plugin
-                if isinstance(param, dict):
-                    param_type = next(iter(param))
-                    if param_type in (
-                        "active-choices",
-                        "active-choices-reactive",
-                        "dynamic-reference",
-                    ):
-                        param[param_type]["_project-name"] = data["name"].split("/")[-1]
-                        param[param_type]["_project-full-name"] = data["name"]
+            for idx, param in enumerate(parameters):
+                if isinstance(parameters, LocList):
+                    param_pos = parameters.value_pos[idx]
+                else:
+                    param_pos = None
+                if not isinstance(param, dict):
+                    # Macro parameter without arguments
+                    param = {param: {}}
+                param_type = next(iter(param))
+                macro_dict = self.registry.macros.get("parameter", {})
+                macro = macro_dict.get(param_type)
+                if not macro:
+                    self._extend_uno_choice_param_data(param, param_type, data)
                 else:
                     # Process macro case.
-                    # TODO: Find a way to do it more properly.
-                    # It's possible has an issue with macro parameter chain,
-                    # when a macro calls another macro with uno-choice plugin parameters.
-                    component = self.registry.parser_data.get("parameter", {}).get(
-                        param
-                    )
-                    for macro_param in component.get("parameters", []):
+                    for macro_param in macro.elements:
                         for macro_param_type in macro_param:
-                            if macro_param_type in (
-                                "active-choices",
-                                "active-choices-reactive",
-                                "dynamic-reference",
-                            ):
-                                macro_param[macro_param_type]["_project-name"] = data[
-                                    "name"
-                                ].split("/")[-1]
-                                macro_param[macro_param_type][
-                                    "_project-full-name"
-                                ] = data["name"]
-
-                self.registry.dispatch("parameter", pdefs, param)
+                            self._extend_uno_choice_param_data(
+                                macro_param, macro_param_type, data
+                            )
+                self.registry.dispatch(
+                    "parameter", pdefs, param, component_pos=param_pos
+                )
