@@ -35,17 +35,17 @@ python str.format() command.
 Job example:
 
     .. literalinclude::
-      /../../tests/yamlparser/fixtures/project_flow_template001.yaml
+      /../../tests/yamlparser/job_fixtures/project_flow_template001.yaml
 
 Job template example:
 
     .. literalinclude::
-      /../../tests/yamlparser/fixtures/project_flow_template002.yaml
+      /../../tests/yamlparser/job_fixtures/project_flow_template002.yaml
 
 Job example runninng a DSL file from the workspace:
 
     .. literalinclude::
-      /../../tests/yamlparser/fixtures/project_flow_template003.yaml
+      /../../tests/yamlparser/job_fixtures/project_flow_template003.yaml
 
 """
 
