@@ -194,6 +194,13 @@ class GithubOrganization(jenkins_jobs.modules.base.Base):
         )
         helpers.convert_mapping_to_xml(factory, data, fopts_map, fail_required=False)
 
+        ####################
+        # Build Strategies #
+        ####################
+
+        if data.get("github-org").get("build-strategies", None):
+            multibranch.build_strategies(xml_parent, data.get("github-org"))
+
         return xml_parent
 
 
@@ -206,6 +213,9 @@ def github_org(xml_parent, data):
         first be configured in Global Configuration. (default GitHub)
     :arg str branch-discovery: Discovers branches on the repository.
         Valid options: no-pr, only-pr, all, false. (default 'no-pr')
+    :arg str repo-name-regex: Regular expression used to match repository names
+        within the organization. (optional)
+        Requires the :jenkins-plugins:`SCM API plugin <scm-api>`.
     :arg list build-strategies: Provides control over whether to build a branch
         (or branch like things such as change requests and tags) whenever it is
         discovered initially or a change from the previous revision has been
@@ -228,14 +238,18 @@ def github_org(xml_parent, data):
         Requires the :jenkins-plugins:`SCM Filter Branch PR Plugin
         <scm-filter-branch-pr>`. Refer to
         :func:`~add_filter_branch_pr_behaviors <project_multibranch.add_filter_branch_pr_behaviors>`.
-    :arg str notification-context: Change the default GitHub check notification
-        context from "continuous-integration/jenkins/SUFFIX" to a custom text,
+    :arg dict notification-context: Change the default GitHub check notification
+        context from "continuous-integration/jenkins/SUFFIX" to a custom label / suffix.
+        (set a label and suffix to true or false, optional)
         Requires the :jenkins-plugins:`Github Custom Notification Context SCM
         Behaviour <github-scm-trait-notification-context>`.
+        Refer to :func:`~add_notification_context_trait <project_multibranch.add_notification_context_trait>`.
     :arg dict property-strategies: Provides control over how to build a branch
         (like to disable SCM triggering or to override the pipeline durability)
         (optional)
         Refer to :func:`~property_strategies <project_multibranch.property_strategies>`.
+    :arg bool exclude-archived-repositories: Whether archived repositories are
+        excluded when scanning an organization. (default: false) (optional)
     :arg bool ssh-checkout: Checkout over SSH.
 
         * **credentials** ('str'): Credentials to use for
@@ -244,8 +258,14 @@ def github_org(xml_parent, data):
     :extensions:
 
         * **clean** (`dict`)
-            * **after** (`bool`) - Clean the workspace after checkout
-            * **before** (`bool`) - Clean the workspace before checkout
+            * **after** (`dict`) - Clean the workspace after checkout
+                * **remove-stale-nested-repos** (`bool`) - Deletes untracked
+                  submodules and any other subdirectories which contain .git directories
+                  (default false)
+            * **before** (`dict`) - Clean the workspace before checkout
+                * **remove-stale-nested-repos** (`bool`) - Deletes untracked
+                  submodules and any other subdirectories which contain .git directories
+                  (default false)
         * **depth** (`int`) - Set shallow clone depth (default 1)
         * **disable-pr-notifications** (`bool`) - Disable default github status
             notifications on pull requests (default false) (Requires the
@@ -376,6 +396,14 @@ def github_org(xml_parent, data):
         rshf = XML.SubElement(traits, "jenkins.scm.impl.trait.RegexSCMHeadFilterTrait")
         XML.SubElement(rshf, "regex").text = data.get("head-filter-regex")
 
+    if data.get("repo-name-regex", None):
+        rssf = XML.SubElement(
+            traits,
+            "jenkins.scm.impl.trait.RegexSCMSourceFilterTrait",
+            {"plugin": "scm-api"},
+        )
+        XML.SubElement(rssf, "regex").text = data.get("repo-name-regex")
+
     if data.get("head-pr-filter-behaviors", None):
         multibranch.add_filter_branch_pr_behaviors(
             traits, data.get("head-pr-filter-behaviors")
@@ -384,17 +412,7 @@ def github_org(xml_parent, data):
     if data.get("property-strategies", None):
         multibranch.property_strategies(xml_parent, data)
 
-    if data.get("build-strategies", None):
-        multibranch.build_strategies(xml_parent, data)
-
-    if data.get("notification-context", None):
-        rshf = XML.SubElement(
-            traits,
-            "org.jenkinsci.plugins.githubScmTraitNotificationContext."
-            "NotificationContextTrait",
-        )
-        XML.SubElement(rshf, "contextLabel").text = data.get("notification-context")
-        XML.SubElement(rshf, "typeSuffix").text = "true"
+    multibranch.add_notification_context_trait(traits, data)
 
     # handle the default git extensions like:
     # - clean
@@ -436,3 +454,9 @@ def github_org(xml_parent, data):
             "".join([disable_github_status_path_dscore, ".DisableStatusUpdateTrait"]),
             {"plugin": "disable-github-multibranch-status"},
         )
+
+    if data.get("exclude-archived-repositories", False):
+        XML.SubElement(
+            traits,
+            "".join([github_path_dscore, ".ExcludeArchivedRepositoriesTrait"]),
+        )
