@@ -33,7 +33,6 @@ Example::
 """
 
 import logging
-import pkg_resources
 import xml.etree.ElementTree as XML
 
 from jenkins_jobs.errors import InvalidAttributeError
@@ -381,9 +380,9 @@ def branch_api(registry, xml_parent, data):
     :arg int number-of-builds: The maximum number of builds allowed within
         the specified time period. (default 1)
     :arg str time-period: The time period within which the maximum number
-        of builds will be enforced. (default 'Hour')
+        of builds will be enforced. (default 'hour')
 
-        :valid values: **Second** **Minute** **Hour**, **Day**, **Week**, **Month**, **Year**
+        :valid values: **second** **minute** **hour**, **day**, **week**, **month**, **year**
     :arg bool skip-rate-limit: Permit user triggered builds to
         skip the rate limit (default false)
 
@@ -404,10 +403,10 @@ def branch_api(registry, xml_parent, data):
     )
     branch.set("plugin", "branch-api")
 
-    valid_time_periods = ["Second", "Minute", "Hour", "Day", "Week", "Month", "Year"]
+    valid_time_periods = ["second", "minute", "hour", "day", "week", "month", "year"]
 
     mapping = [
-        ("time-period", "durationName", "Hour", valid_time_periods),
+        ("time-period", "durationName", "hour", valid_time_periods),
         ("number-of-builds", "count", 1),
         ("skip-rate-limit", "userBoost", False),
     ]
@@ -479,10 +478,9 @@ def inject(registry, xml_parent, data):
     helpers.convert_mapping_to_xml(info, data, mapping, fail_required=False)
 
     # determine version of plugin
-    plugin_info = registry.get_plugin_info("Groovy")
-    version = pkg_resources.parse_version(plugin_info.get("version", "0"))
+    plugin_ver = registry.get_plugin_version("Groovy")
 
-    if version >= pkg_resources.parse_version("2.0.0"):
+    if plugin_ver >= "2.0.0":
         secure_groovy_script = XML.SubElement(info, "secureGroovyScript")
         mapping = [
             ("groovy-content", "script", None),
@@ -530,10 +528,30 @@ def authenticated_build(registry, xml_parent, data):
 def authorization(registry, xml_parent, data, job_data):
     """yaml: authorization
     Specifies an authorization matrix
+    In 3.0 version of plugin was added support for explicitly assigning permissions
+    to groups or users with a given name to prevent confusion when names match either.
 
     .. _authorization:
 
+    For *matrix-auth >= 3.0*
+    :arg list <inheritance-strategy>: `<inheritance-strategy>` the name of inheritance strategy
+
+        :<inheritance-strategy> values:
+            * **parent**
+            * **global**
+            * **none**
+
+    :arg list prefix:<name>:
+            * `prefix`
+                * **GROUP**
+                * **USER**
+            * `<name>` is the name of the group or user, containing
+
+    For *matrix-auth < 3.0*
+
     :arg list <name>: `<name>` is the name of the group or user, containing
+
+
         the list of rights to grant.
 
        :<name> rights:
@@ -560,7 +578,7 @@ def authorization(registry, xml_parent, data, job_data):
 
     Example:
 
-    .. literalinclude:: /../../tests/properties/fixtures/authorization.yaml
+    .. literalinclude:: /../../tests/properties/fixtures/authorization01.yaml
        :language: yaml
     """
 
@@ -598,21 +616,41 @@ def authorization(registry, xml_parent, data, job_data):
         else:
             element_name = "hudson.security.AuthorizationMatrixProperty"
         matrix = XML.SubElement(xml_parent, element_name)
+
+        inheritance_strategy = (
+            "org.jenkinsci.plugins.matrixauth.inheritance.InheritParentStrategy"
+        )
+        if data.get("inheritance-strategy") == "global":
+            inheritance_strategy = (
+                "org.jenkinsci.plugins.matrixauth.inheritance.InheritGlobalStrategy"
+            )
+        elif data.get("inheritance-strategy") == "none":
+            inheritance_strategy = (
+                "org.jenkinsci.plugins.matrixauth.inheritance.NonInheritingStrategy"
+            )
         XML.SubElement(
             matrix,
             "inheritanceStrategy",
-            {
-                "class": "org.jenkinsci.plugins.matrixauth.inheritance.InheritParentStrategy"
-            },
+            {"class": inheritance_strategy},
         )
 
         for (username, perms) in data.items():
-            for perm in perms:
-                pe = XML.SubElement(matrix, "permission")
-                try:
-                    pe.text = "{0}:{1}".format(mapping[perm], username)
-                except KeyError:
-                    raise InvalidAttributeError(username, perm, mapping.keys())
+            if username != "inheritance-strategy":
+                for perm in perms:
+                    pe = XML.SubElement(matrix, "permission")
+                    try:
+                        if username.upper().startswith(
+                            "GROUP:"
+                        ) or username.upper().startswith("USER:"):
+                            pe.text = "{0}:{1}:{2}".format(
+                                username.split(":")[0].upper(),
+                                mapping[perm],
+                                username.split(":")[1],
+                            )
+                        else:
+                            pe.text = "{0}:{1}".format(mapping[perm], username)
+                    except KeyError:
+                        raise InvalidAttributeError(username, perm, mapping.keys())
 
 
 def priority_sorter(registry, xml_parent, data):
@@ -631,17 +669,16 @@ def priority_sorter(registry, xml_parent, data):
         /../../tests/properties/fixtures/priority_sorter002.yaml
        :language: yaml
     """
-    plugin_info = registry.get_plugin_info("PrioritySorter")
-    version = pkg_resources.parse_version(plugin_info.get("version", "0"))
+    plugin_ver = registry.get_plugin_version("PrioritySorter")
 
-    if version >= pkg_resources.parse_version("3.0"):
+    if plugin_ver >= "3.0":
         priority_sorter_tag = XML.SubElement(
             xml_parent,
             "jenkins.advancedqueue.jobinclusion." "strategy.JobInclusionJobProperty",
         )
 
         mapping = [("use", "useJobGroup", True), ("priority", "jobGroupName", None)]
-    elif version >= pkg_resources.parse_version("2.0"):
+    elif plugin_ver >= "2.0":
         priority_sorter_tag = XML.SubElement(
             xml_parent, "jenkins.advancedqueue.priority." "strategy.PriorityJobProperty"
         )
@@ -931,10 +968,9 @@ def slack(registry, xml_parent, data):
     """
     logger = logging.getLogger(__name__)
 
-    plugin_info = registry.get_plugin_info("Slack Notification Plugin")
-    plugin_ver = pkg_resources.parse_version(plugin_info.get("version", "0"))
+    plugin_ver = registry.get_plugin_version("Slack Notification Plugin")
 
-    if plugin_ver >= pkg_resources.parse_version("2.0"):
+    if plugin_ver >= "2.0":
         logger.warning("properties section is not used with plugin version >= 2.0")
 
     mapping = (
@@ -1031,6 +1067,33 @@ def build_discarder(registry, xml_parent, data):
     helpers.convert_mapping_to_xml(strategy, data, mappings, fail_required=True)
 
 
+def build_failure_analyzer(registry, xml_parent, data):
+    """yaml: build-failure-analyzer
+
+    Controls failure cause analysis for builds.
+    Requires the Jenkins :jenkins-plugins:`Build Failure Analyzer Plugin
+    <build-failure-analyzer>`.
+
+    Example:
+
+    .. literalinclude::
+        /../../tests/properties/fixtures/build-failure-analyzer-001.yaml
+       :language: yaml
+
+    .. literalinclude::
+        /../../tests/properties/fixtures/build-failure-analyzer-003.yaml
+       :language: yaml
+    """
+    base_sub = XML.SubElement(
+        xml_parent, "com.sonyericsson.jenkins.plugins.bfa.model.ScannerJobProperty"
+    )
+
+    mappings = [
+        ("disabled", "doNotScan", False),
+    ]
+    helpers.convert_mapping_to_xml(base_sub, data, mappings, fail_required=True)
+
+
 def slave_prerequisites(registry, xml_parent, data):
     """yaml: slave-prerequisites
     This plugin allows you to check prerequisites on slave before
@@ -1463,9 +1526,10 @@ class Properties(jenkins_jobs.modules.base.Base):
     component_list_type = "properties"
 
     def gen_xml(self, xml_parent, data):
-        properties = xml_parent.find("properties")
-        if properties is None:
-            properties = XML.SubElement(xml_parent, "properties")
+        xml_properties = xml_parent.find("properties")
+        if xml_properties is None:
+            xml_properties = XML.SubElement(xml_parent, "properties")
 
-        for prop in data.get("properties", []):
-            self.registry.dispatch("property", properties, prop, job_data=data)
+        self.dispatch_component_list(
+            "property", data.get("properties", []), xml_properties, job_data=data
+        )
