@@ -39,6 +39,7 @@ Example of an empty ``scm``:
 import logging
 import xml.etree.ElementTree as XML
 
+from jenkins_jobs.loc_loader import LocList
 from jenkins_jobs.errors import InvalidAttributeError
 from jenkins_jobs.errors import JenkinsJobsException
 import jenkins_jobs.modules.base
@@ -221,7 +222,7 @@ def git(registry, xml_parent, data):
 
         :browsers supported:
             * **auto** - (default)
-            * **assemblaweb** - https://www.assembla.com/home
+            * **assemblaweb** - https://get.assembla.com/
             * **bitbucketweb** - https://bitbucket.org/
             * **cgit** - https://git.zx2c4.com/cgit/about/
             * **fisheye** - https://www.atlassian.com/software/fisheye
@@ -229,10 +230,10 @@ def git(registry, xml_parent, data):
             * **githubweb** - https://github.com/
             * **gitiles** - https://code.google.com/archive/p/gitiles/
             * **gitlab** - https://about.gitlab.com/
-            * **gitlist** - http://gitlist.org/
+            * **gitlist** - https://gitlist.org/
             * **gitoriousweb** - https://gitorious.org/
             * **gitweb** - https://git-scm.com/docs/gitweb
-            * **kiln** - https://www.fogbugz.com/version-control
+            * **kiln** - https://ignitetech.com/softwarelibrary/fogbugz
             * **microsoft\-tfs\-2013** - |tfs_2013|
             * **phabricator** - https://www.phacility.com/
             * **redmineweb** - https://www.redmine.org/
@@ -262,8 +263,14 @@ def git(registry, xml_parent, data):
             to build. Can be one of `default`,`inverse`, or `gerrit`
             (default 'default')
         * **clean** (`dict`)
-            * **after** (`bool`) - Clean the workspace after checkout
-            * **before** (`bool`) - Clean the workspace before checkout
+            * **after** (`dict`) - Clean the workspace after checkout
+                * **remove-stale-nested-repos** (`bool`) - Deletes untracked
+                  submodules and any other subdirectories which contain .git directories
+                  (default false)
+            * **before** (`dict`) - Clean the workspace before checkout
+                * **remove-stale-nested-repos** (`bool`) - Deletes untracked
+                  submodules and any other subdirectories which contain .git directories
+                  (default false)
         * **committer** (`dict`)
             * **name** (`str`) - Name to use as author of new commits
             * **email** (`str`) - E-mail address to use for new commits
@@ -338,7 +345,7 @@ def git(registry, xml_parent, data):
     .. literalinclude:: /../../tests/scm/fixtures/git001.yaml
 
     .. |tfs_2013| replace::
-        https://azure.microsoft.com/en-us/services/devops/server
+        https://azure.microsoft.com/en-us/products/devops/server/
 
     """
     logger = logging.getLogger("%s:git" % __name__)
@@ -413,7 +420,7 @@ def git(registry, xml_parent, data):
         xe = XML.SubElement(scm, xmlname, attrs)
         if optname and optname in data:
             val = data[optname]
-        if type(val) == bool:
+        if type(val) is bool:
             xe.text = str(val).lower()
         else:
             xe.text = val
@@ -518,7 +525,17 @@ def git_extensions(xml_parent, data):
         else:
             clean_after = data["clean"].get("after", False)
             clean_before = data["clean"].get("before", False)
-        if clean_after:
+        if clean_after is not False:
+            if isinstance(clean_after, bool):
+                clean_after_opts = {}
+                logger.warning(
+                    "'clean: after: bool' configuration format is deprecated, "
+                    "after should be an empty dict or filled with accepted "
+                    "options."
+                )
+            else:
+                clean_after_opts = clean_after
+
             ext_name = impl_prefix + "CleanCheckout"
             if trait:
                 trait_name = "CleanAfterCheckoutTrait"
@@ -526,7 +543,20 @@ def git_extensions(xml_parent, data):
                 ext = XML.SubElement(tr, "extension", {"class": ext_name})
             else:
                 ext = XML.SubElement(xml_parent, ext_name)
-        if clean_before:
+            if "remove-stale-nested-repos" in clean_after_opts:
+                elm = XML.SubElement(ext, "deleteUntrackedNestedRepositories")
+                elm.text = "true"
+        if clean_before is not False:
+            if isinstance(clean_before, bool):
+                clean_before_opts = {}
+                logger.warning(
+                    "'clean: before: bool' configuration format is deprecated, "
+                    "before should be an empty dict or filled with accepted "
+                    "options."
+                )
+            else:
+                clean_before_opts = clean_before
+
             ext_name = impl_prefix + "CleanBeforeCheckout"
             if trait:
                 trait_name = "CleanBeforeCheckoutTrait"
@@ -534,6 +564,9 @@ def git_extensions(xml_parent, data):
                 ext = XML.SubElement(tr, "extension", {"class": ext_name})
             else:
                 ext = XML.SubElement(xml_parent, ext_name)
+            if "remove-stale-nested-repos" in clean_before_opts:
+                elm = XML.SubElement(ext, "deleteUntrackedNestedRepositories")
+                elm.text = "true"
     committer = data.get("committer", {})
     if committer:
         ext_name = impl_prefix + "UserIdentity"
@@ -909,6 +942,9 @@ def repo(registry, xml_parent, data):
     :arg bool reset-first: Remove any commits that are not on the repositories
         by running the following command before anything else (default false):
         ``repo forall -c "git reset --hard"``
+    :arg bool clean-first: Remove any files that are not tracked in the repositories
+        by running the following command before anything else (default false):
+        ``repo forall -c "git clean -fdx"``
     :arg bool quiet: Make repo more quiet
         (default true)
     :arg bool force-sync: Continue sync even if a project fails to sync
@@ -935,6 +971,7 @@ def repo(registry, xml_parent, data):
         ("depth", "depth", 0),
         ("current-branch", "currentBranch", True),
         ("reset-first", "resetFirst", False),
+        ("clean-first", "cleanFirst", False),
         ("quiet", "quiet", True),
         ("force-sync", "forceSync", False),
         ("no-tags", "noTags", False),
@@ -1174,7 +1211,7 @@ def tfs(registry, xml_parent, data):
     Specifies the Team Foundation Server repository for this job.
 
     Requires the Jenkins Team Foundation Server Plugin
-    (https://github.com/jenkinsci/tfs-plugin).
+    (:jenkins-github:`tfs-plugin`).
 
     **NOTE**: TFS Password must be entered manually on the project if a
     user name is specified. The password will be overwritten with an empty
@@ -1339,8 +1376,8 @@ def hg(self, xml_parent, data):
             * **bitbucketweb** - https://bitbucket.org/
             * **fisheye** - https://www.atlassian.com/software/fisheye
             * **googlecode** - https://code.google.com/
-            * **hgweb** - https://www.mercurial-scm.org/repo/hg/help/hgweb
-            * **kilnhg** - https://www.fogbugz.com/version-control
+            * **hgweb** - https://repo.mercurial-scm.org/hg/help/hgweb
+            * **kilnhg** - https://ignitetech.com/softwarelibrary/fogbugz
             * **rhodecode** - https://rhodecode.com/ (versions >= 1.2)
             * **rhodecode-pre-1.2.0** - https://rhodecode.com/ (versions < 1.2)
 
@@ -1737,8 +1774,8 @@ class SCM(jenkins_jobs.modules.base.Base):
             return
 
         scms_parent = XML.Element("scms")
-        for scm in data.get("scm", []):
-            self.registry.dispatch("scm", scms_parent, scm)
+        component_list = data.get("scm", [])
+        self.dispatch_component_list("scm", component_list, scms_parent)
         scms_count = len(scms_parent)
         if scms_count == 0:
             XML.SubElement(xml_parent, "scm", {"class": "hudson.scm.NullSCM"})
@@ -1774,7 +1811,14 @@ class PipelineSCM(jenkins_jobs.modules.base.Base):
             if scms_count == 0:
                 raise JenkinsJobsException("'scm' missing or empty")
             elif scms_count == 1:
-                self.registry.dispatch("scm", definition_parent, scms[0])
+                component = scms[0]
+                if isinstance(scms, LocList):
+                    component_pos = scms.value_pos[0]
+                else:
+                    component_pos = None
+                self.registry.dispatch(
+                    "scm", definition_parent, component, component_pos=component_pos
+                )
                 mapping = [
                     ("script-path", "scriptPath", "Jenkinsfile"),
                     ("lightweight-checkout", "lightweight", None, [True, False]),
