@@ -17,10 +17,11 @@
 
 import hashlib
 import pkg_resources
+import sys
 from xml.dom import minidom
 import xml.etree.ElementTree as XML
 
-from jenkins_jobs import errors
+from jenkins_jobs.errors import JenkinsJobsException
 
 __all__ = ["XmlJobGenerator", "XmlJob"]
 
@@ -53,7 +54,13 @@ class XmlJob(object):
         self.name = name
 
     def md5(self):
-        return hashlib.md5(self.output()).hexdigest()
+        if sys.version_info[:2] >= (3, 6):
+            # allows md5 use on fips-enabled systems
+            hash_func = hashlib.new("md5", usedforsecurity=False)
+            hash_func.update(self.output())
+            return hash_func.hexdigest()
+        else:
+            return hashlib.md5(self.output()).hexdigest()
 
     def output(self):
         out = minidom.parseString(XML.tostring(self.xml, encoding="UTF-8"))
@@ -76,7 +83,10 @@ class XmlGenerator(object):
     def generateXML(self, data_list):
         xml_objs = []
         for data in data_list:
-            xml_objs.append(self._getXMLForData(data))
+            try:
+                xml_objs.append(self._getXMLForData(data.data))
+            except JenkinsJobsException as x:
+                raise x.with_ctx_list(data.context)
         return xml_objs
 
     def _getXMLForData(self, data):
@@ -97,7 +107,7 @@ class XmlGenerator(object):
             ep.name
             for ep in pkg_resources.iter_entry_points(group=self.entry_point_group)
         ]
-        raise errors.JenkinsJobsException(
+        raise JenkinsJobsException(
             "Unrecognized {}: {} (supported types are: {})".format(
                 self.kind_attribute, kind, ", ".join(names)
             )
