@@ -15,13 +15,25 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import os
+from operator import attrgetter
+from pathlib import Path
 
+import pytest
+
+from tests.enum_scenarios import scenario_list
 from jenkins_jobs.modules import general
-from tests import base
 
 
-class TestCaseModuleGeneral(base.BaseScenariosTestCase):
-    fixtures_path = os.path.join(os.path.dirname(__file__), "fixtures")
-    scenarios = base.get_scenarios(fixtures_path)
-    klass = general.General
+fixtures_dir = Path(__file__).parent / "fixtures"
+
+
+@pytest.fixture(
+    params=scenario_list(fixtures_dir),
+    ids=attrgetter("name"),
+)
+def scenario(request):
+    return request.param
+
+
+def test_yaml_snippet(check_generator):
+    check_generator(general.General)
